// clang-format off

#define PREFIX "user/examples/yamlcpp/"

ksNew (20,
       keyNew (PREFIX "bloc/party/little", KEY_VALUE, "thoughts", KEY_END),
       keyNew (PREFIX "bloc/party/silent", KEY_VALUE, "alarm", KEY_END),
       keyNew (PREFIX "flow/foetus", KEY_VALUE, "2001", KEY_END),
       keyNew (PREFIX "nest/captain", KEY_VALUE, "planet", KEY_END),
       keyNew (PREFIX "nest/todd", KEY_VALUE, "anderson", KEY_END),
       keyNew (PREFIX "nest/josé", KEY_VALUE, "gonzález", KEY_END),
       keyNew (PREFIX "flow/foetus", KEY_VALUE, "2001", KEY_END),
       KS_END)
